==> rotools-0.1.28-py3-none-any.whl: ROTools/Config/Config.py <==
import os

from ROTools.Helpers.Attr import setattr_ex, getattr_ex
from ROTools.Helpers.DumpBase import DumpBase

class Config(DumpBase):
    def __init__(self, **kwargs):
        for k in kwargs.keys():
            setattr(self, k, kwargs[k])

    def add_env_data(self, prefix):
        extra_config = [(key[len(prefix):].lower(), value) for key, value in os.environ.items() if key.startswith(prefix)]

        for key, value in extra_config:
            _old_value = getattr_ex(self, key)
            if _old_value is not None and isinstance(_old_value, bool):
                setattr_ex(self, key, value in ["true", "True", "TRUE", "1", ])
                continue

            if _old_value is not None and isinstance(_old_value, int):
                setattr_ex(self, key, int(value))
                continue

            if _old_value is not None and isinstance(_old_value, float):
                setattr_ex(self, key, float(value))
                continue

            setattr_ex(self, key, value)

    def get_redis(self):
        if not hasattr(self, "redis"):
            return None

        redis_wrapper = getattr(self, "_redis_wrapper", None)
        if redis_wrapper is None:
            import redis
            redis_wrapper = redis.Redis(decode_responses=True, **self.redis.__dict__)
            setattr(self, "_redis_wrapper", redis_wrapper)
        return redis_wrapper

    def get_minio(self):
        if not hasattr(self, "minio"):
            return None

        mimo_wrapper = getattr(self, "_mimo_wrapper", None)
        if mimo_wrapper is None:
            from minio import Minio
            from ROTools.Wrappers.MinioWrapper import MinioWrapper
            mimo_wrapper = MinioWrapper(Minio(**self.minio.__dict__))
            setattr(self, "_mimo_wrapper", mimo_wrapper)
        return mimo_wrapper

    def dump_config(self):
        print()
        print("========")
        self.dump()
        print("========")
        print()

==> rotools-0.1.31-py3-none-any.whl: ROTools/Config/Config.py <==
import os

from ROTools.Helpers.Attr import setattr_ex, getattr_ex
from ROTools.Helpers.DumpBase import DumpBase

class Config(DumpBase):
    def __init__(self, **kwargs):
        for k in kwargs.keys():
            setattr(self, k, kwargs[k])

    def add_env_data(self, prefix):
        extra_config = [(key[len(prefix):].lower(), value) for key, value in os.environ.items() if key.startswith(prefix)]

        for key, value in extra_config:
            _old_value = getattr_ex(self, key)
            if _old_value is not None and isinstance(_old_value, bool):
                setattr_ex(self, key, value in ["true", "True", "TRUE", "1", ])
                continue

            if _old_value is not None and isinstance(_old_value, int):
                setattr_ex(self, key, int(value))
                continue

            if _old_value is not None and isinstance(_old_value, float):
                setattr_ex(self, key, float(value))
                continue

            setattr_ex(self, key, value)

    def get_redis(self):
        if not hasattr(self, "redis"):
            return None

        redis_wrapper = getattr(self, "_redis_wrapper", None)
        if redis_wrapper is None:
            import redis
            redis_wrapper = redis.Redis(decode_responses=False, **self.redis.__dict__)
            setattr(self, "_redis_wrapper", redis_wrapper)
        return redis_wrapper

    def get_minio(self):
        if not hasattr(self, "minio"):
            return None

        mimo_wrapper = getattr(self, "_mimo_wrapper", None)
        if mimo_wrapper is None:
            from minio import Minio
            from ROTools.Wrappers.MinioWrapper import MinioWrapper
            mimo_wrapper = MinioWrapper(Minio(**self.minio.__dict__))
            setattr(self, "_mimo_wrapper", mimo_wrapper)
        return mimo_wrapper

    def dump_config(self):
        print()
        print("========")
        self.dump()
        print("========")
        print()
